| Title: | R Interface to Yandex Translate API |
|---|---|
| Description: | 'Yandex Translate' (https://translate.yandex.com/) is a statistical machine translation system. The system translates separate words, complete texts, and webpages. This package can be used to detect language from text and to translate it to supported target language. For more info: https://tech.yandex.com/translate/doc/dg/concepts/About-docpage/ |
| Authors: | Mukul Chaware[aut,cre] |
| Maintainer: | Mukul Chaware <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0 |
| Built: | 2026-05-10 05:10:06 UTC |
| Source: | https://github.com/mukul13/ryandextranslate |
Detects the language of the specified text.
detect_language(api_key, text = "")detect_language(api_key, text = "")
api_key |
yandex API key |
text |
The text to detect the language for |
data frame giving detected language
## Not run: data=detect_language(api_key,text="how are you?") ## End(Not run)## Not run: data=detect_language(api_key,text="how are you?") ## End(Not run)
Gets a list of translation directions supported by the service
get_translation_direction(api_key, lang = "")get_translation_direction(api_key, lang = "")
api_key |
yandex API key |
lang |
If set, the response contains explanations of language codes. Language names are output in the language corresponding to the code in this parameter. |
data frame giving supported translation direction
## Not run: data=get_translation_direction(api_key) ## End(Not run)## Not run: data=get_translation_direction(api_key) ## End(Not run)
Translates text to the specified language
translate(api_key, text = "", lang = "")translate(api_key, text = "", lang = "")
api_key |
yandex API key |
text |
The text to translate.The maximum size of the text being passed is 10000 characters. |
lang |
The translation direction.You can use any of the following ways to set it:As a pair of language codes separated by a hyphen ("from"-"to"). For example, en-ru indicates translating from English to Russian.As the final language code (for example, ru). In this case, the service tries to detect the source language automatically. |
data frame giving translated text
## Not run: data=translate(api_key,text="how are you?",lang="hi") ## End(Not run)## Not run: data=translate(api_key,text="how are you?",lang="hi") ## End(Not run)